import { world, system, EntityDamageCause, BlockComponent } from '@minecraft/server';

world.beforeEvents.worldInitialize.subscribe(initEvent => {
    initEvent.blockComponentRegistry.registerCustomComponent('magma:start_stepping', {
        onStepOn: e => {
            const { entity, block } = e;
            const stepping = block.permutation.withState("custom:magma", true);
            block.setPermutation(stepping);
            if(entity !== undefined && entity.typeId == "minecraft:player" && entity.isSneaking === false && entity.typeId !== "minecraft:item") {
                if (block.typeId == "js:acid_bag") {
                    entity.addEffect("poison", 5*20, {showParticles: false, amplifier: 0})
                    entity.addEffect("slowness", 1*20, {showParticles: false, amplifier: 2})
                } 
                
                if (block.typeId == "js:magma_acid") {
                    entity.applyDamage(5,{ cause: EntityDamageCause.magma });
                    entity.addEffect("slowness", 1*20, {showParticles: false, amplifier: 1})
                }
            }
        },
    });
    initEvent.blockComponentRegistry.registerCustomComponent('magma:stepping', {
        onTick: e => {
            const { block } = e;
            const {x,y,z} = block.location;
            system.run(() => {
                const entities = block.dimension.getEntities({
                    location:{ x: block.location.x + 0.5, y: block.location.y + 0.8, z: block.location.z + 0.5 },
                    maxDistance: 1.0
                });
                for(const entity of entities) {
                    if(entity !== undefined && entity.typeId == "minecraft:player" && entity.isSneaking === false && entity.typeId !== "minecraft:item") {
                        if (block.typeId == "js:acid_bag") {
                            entity.addEffect("poison", 5*20, {showParticles: false, amplifier: 0})
                            entity.addEffect("slowness", 1*20, {showParticles: false, amplifier: 2})
                        } 
                        
                        if (block.typeId == "js:magma_acid") {
                            entity.applyDamage(5,{ cause: EntityDamageCause.magma });
                            entity.addEffect("slowness", 1*20, {showParticles: false, amplifier: 1})
                        }
                    }
                };
            });
        }
    });
    initEvent.blockComponentRegistry.registerCustomComponent('magma:jumping', {
        onEntityFallOn: e => {
            const { entity, block } = e;
            const stepping = block.permutation.withState("custom:magma", true);
            block.setPermutation(stepping);
            if(entity !== undefined && entity.typeId == "minecraft:player" && entity.isSneaking === false && entity.typeId !== "minecraft:item") {
                if (block.typeId == "js:acid_bag") {
                    entity.addEffect("poison", 5*20, {showParticles: false, amplifier: 0})
                    entity.addEffect("slowness", 1*20, {showParticles: false, amplifier: 2})
                } 
                
                if (block.typeId == "js:magma_acid") {
                    entity.applyDamage(5,{ cause: EntityDamageCause.magma });
                    entity.addEffect("slowness", 1*20, {showParticles: false, amplifier: 1})
                }
            }
        },
    });
    initEvent.blockComponentRegistry.registerCustomComponent('magma:stop_stepping', {
        onStepOff: e => {
            const { entity, block } = e;
            const stepping = block.permutation.withState("custom:magma", false);
            block.setPermutation(stepping);
        },
    });
    initEvent.blockComponentRegistry.registerCustomComponent('js:flicker', {
        onTick: e => {
            const { block } = e;
            const flicker = block.permutation.withState("js:flicker", 1);
            block.setPermutation(flicker);
        },
    });
    initEvent.blockComponentRegistry.registerCustomComponent('js:flicker2', {
        onTick: e => {
            const { block } = e;
            const flicker = block.permutation.withState("js:flicker", 2);
            block.setPermutation(flicker);
        },
    });
    initEvent.blockComponentRegistry.registerCustomComponent('js:flicker3', {
        onTick: e => {
            const { block } = e;
            const flicker = block.permutation.withState("js:flicker", 3);
            block.setPermutation(flicker);
        },
    });
    initEvent.blockComponentRegistry.registerCustomComponent('js:flicker4', {
        onTick: e => {
            const { block } = e;
            const flicker = block.permutation.withState("js:flicker", 0);
            block.setPermutation(flicker);
        },
    });
    initEvent.blockComponentRegistry.registerCustomComponent('js:poster', {
        onTick: e => {
            const { block } = e;
            const posterState = block.permutation.getState("js:poster_image");
          //  console.warn(posterState)
    
            const newState = posterState === 4 ? 1 : posterState + 1;

           // console.warn(newState)
    
            block.setPermutation(block.permutation.withState("js:poster_image", parseInt(newState)));
        },
    });


    initEvent.blockComponentRegistry.registerCustomComponent('js:display', {
        onPlayerInteract: e => {
            const { player, block } = e;
            
            player.runCommand(`playsound random.orb @s`)
            if (block.typeId == "js:armour2") {
                player.sendMessage('§7>>§e Armour II §7increases defence points to 20.§r')
            }
            if (block.typeId == "js:armour3") {
                player.sendMessage('§7>>§e Armour III §7grants permanent Resistance I effect.§r')
            }
            if (block.typeId == "js:dash_lv2") {
                player.sendMessage('§7>>§e Dash II §7decreases dash cooldown time by half.§r')
            }
            if (block.typeId == "js:dash_unlock") {
                player.sendMessage('§7>>§e Dash §7can prove useful in tight situations.§r')
            }
            if (block.typeId == "js:fahmie_easter_egg") {
                player.sendMessage('§7<!>§e Fahmie - By §bMecha§r')
            }
            if (block.typeId == "js:health2") {
                player.sendMessage('§7>>§e Health II §7increases your health to 40HP.§r')
            }
            if (block.typeId == "js:heat1") {
                player.sendMessage('§7>>§e Heat I §7decreases time for Praedo to cool down.§r')
            }
            if (block.typeId == "js:heat2") {
                player.sendMessage('§7>>§e Heat II §7further decreases time for Praedo to cool down.§r')
            }
            if (block.typeId == "js:lifesteal") {
                player.sendMessage('§7>>§e Lifesteal §7allows you to regain health whenever you do damage.§r')
            }
            if (block.typeId == "js:luck1") {
                player.sendMessage('§7>>§e Luck I §7increases the chance of ammo dropping from hitting enemies using the XR-A5.§r')
                player.sendMessage('§7>>§7 It also gives a small chance for Praetereo/Praedo ammo and NG-L7 ammo to drop.§r')
            }
            if (block.typeId == "js:luck2") {
                player.sendMessage('§7>>§e Luck II §7makes all weapon hits have a chance of dropping ammo, but rarer ammo still only drops for XR-A5 hits.§r')
            }
            if (block.typeId == "js:mini_js_dy") {
                player.sendMessage('§7<!>§e Mini JS 2 - By §bDyDyOOF§r')
            }
            if (block.typeId == "js:mini_js_easter_egg") {
                player.sendMessage('§7<!>§e Mini JS - By §bIcephoenix89907§r')
            }
            if (block.typeId == "js:mrx15_lv2") {
                player.sendMessage('§7>>§e MRX-15 II §7increases ammo capacity by 10.§r')
            }
            if (block.typeId == "js:mrx15_lv3") {
                player.sendMessage('§7>>§e MRX-15 III §7increases ammo capacity by 10.§r')
            }
            if (block.typeId == "js:ngl7_lv2") {
                player.sendMessage('§7>>§e NG-L7 II §7increases ammo capacity by 1.§r')
            }
            if (block.typeId == "js:ngl7_lv3") {
                player.sendMessage('§7>>§e NG-L7 III §7increases ammo capacity by 1.§r')
            }
            if (block.typeId == "js:ngl7_unlock") {
                player.sendMessage('§7>>§e NG-L7 §7is a rocket launcher that does tremendous damage.§r')
            }
            if (block.typeId == "js:project80_lv2") {
                player.sendMessage('§7>>§e Project-80 II §7increases ammo capacity by 8.§r')
            }
            if (block.typeId == "js:project80_lv3") {
                player.sendMessage('§7>>§e Project-80 III §7increases ammo capacity by 8.§r')
            }
            if (block.typeId == "js:project80_unlock") {
                player.sendMessage('§7>>§e Project-80 II §7is a burst fire weapon, effective against Brutes.§r')
            }
            if (block.typeId == "js:speed2") {
                player.sendMessage('§7>>§e Speed II §7grants speed II.§r')
            }
            if (block.typeId == "js:speed3") {
                player.sendMessage('§7>>§e Speed III §7grants speed III.§r')
            }
            if (block.typeId == "js:xra5_lv2") {
                player.sendMessage('§7>>§e XR-A5 II §7increases ammo capacity by 10.§r')
            }
            if (block.typeId == "js:xra5_lv3") {
                player.sendMessage('§7>>§e XR-A5 III §7increases ammo capacity by 10.§r')
            }
            
        },
    });


    
    initEvent.itemComponentRegistry.registerCustomComponent('js:dash', {
        onUse: e => {
            const { itemStack, source } = e;
            let cooldownData = source.getItemCooldown("dash");
          //  console.warn(cooldownData)
            if (cooldownData == 59) {
              source.sendMessage(`hud_overlay_dash`)
              source.dimension.playSound('music.dash', source.location, { volume: 1, pitch: 1})
              source.addTag("dash")
              source.startItemCooldown("dash", 60);
            }
        },
    });
    //Slighty Gay -Bonnie
    
    initEvent.itemComponentRegistry.registerCustomComponent('js:dash2', {
        onUse: e => {
            const { itemStack, source } = e;
            let cooldownData = source.getItemCooldown("dash2");
          //  console.warn(cooldownData)
            if (cooldownData == 29) {
              source.sendMessage(`hud_overlay_dash`)
              source.dimension.playSound('music.dash', source.location, { volume: 1, pitch: 1})
              source.addTag("dash")
              source.startItemCooldown("dash", 30);
            }
        },
    });

    
    initEvent.itemComponentRegistry.registerCustomComponent('js:infinite_ammo', {
        onUse: e => {
            const { itemStack, source } = e;
            let cooldownData = source.getItemCooldown("infinite_ammo");
          //  console.warn(cooldownData)
            if (cooldownData == 99) {
              const lobby = world.scoreboard.getObjective("lobby") 

              const score = lobby.getScore(source)
            //  console.warn(score)
              if (score == 1) {
                source.runCommand(`tellraw @a {"rawtext":[{"text":"§7[!] §eInfinite Ammo §cDisabled.§r"}]}`)
                source.runCommand(`playsound random.orb @s`)
                source.runCommand(`replaceitem entity @s[tag=has_inf_ammo_cheat_code] slot.weapon.mainhand 0 js:infinite_ammo 1 0 {"minecraft:item_lock":{"mode":"lock_in_inventory"}}`)
                source.removeTag("infinite_ammo2")
              } else {
                source.runCommand(`tellraw @s {"rawtext":[{"text":"§7[!] §cYou cannot toggle §eCheat Codes§c during a match.§r"}]}`)
                source.runCommand(`playsound block.false_permissions @s`)
              }
              source.startItemCooldown("infinite_ammo", 100);
            }
        },
    });

    
    initEvent.itemComponentRegistry.registerCustomComponent('js:infinite_ammo2', {
        onUse: e => {
            const { itemStack, source } = e;
            let cooldownData = source.getItemCooldown("infinite_ammo");
          //  console.warn(cooldownData)
            if (cooldownData == 99) {
              const lobby = world.scoreboard.getObjective("lobby") 

              const score = lobby.getScore(source)
          //    console.warn(score)
              if (score == 1) {
                
                source.runCommand(`tellraw @a {"rawtext":[{"text":"§7[!] §eInfinite Ammo §aEnabled.§r"}]}`)
                source.runCommand(`tellraw @a {"rawtext":[{"text":"§7[!] §eThere are §cNO xp rewards§e when infinite ammo is enabled.§r"}]}`)
                source.runCommand(`playsound random.orb @s`)
                source.runCommand(`replaceitem entity @s[tag=has_inf_ammo_cheat_code] slot.weapon.mainhand 0 js:infinite_ammo_active 1 0 {"minecraft:item_lock":{"mode":"lock_in_inventory"}}`)
                source.runCommand(`tag @s add infinite_ammo2`)
                            
              } else {
                source.runCommand(`tellraw @s {"rawtext":[{"text":"§7[!] §cYou cannot toggle §eCheat Codes§c during a match.§r"}]}`)
                source.runCommand(`playsound block.false_permissions @s`)
              }
              source.startItemCooldown("infinite_ammo", 100);
            }
        },
    });

});
